pub struct Input {
pub system: Option<FHIRUri>,
pub version: Option<FHIRString>,
pub property: Option<Vec<InputProperty>>,
pub exact: FHIRBoolean,
pub compositional: Option<FHIRBoolean>,
}Fields
system: Option<FHIRUri>The system in which composition is to be performed. This must be provided unless the operation is invoked on a code system instance
version: Option<FHIRString>The version of the system for the inferencing to be performed
property: Option<Vec<InputProperty>>One or more properties that contain information to be composed into the code
exact: FHIRBooleanWhether the operation is being used by a human (‘false’), or a machine (‘true’). If the operation is being used by a human, the terminology server can return a list of possible matches, with commentary. For a machine, the server returns complete or partial matches, not possible matches. The default value is ‘false’
compositional: Option<FHIRBoolean>Post-coordinated expressions are allowed to be returned in the matching codes (mainly for SNOMED CT). Default = false